==> uniforms-semantic-1.8.2.tgz: package/src/RadioField.js <==
import React          from 'react';
import classnames     from 'classnames';
import connectField   from 'uniforms/connectField';
import filterDOMProps from 'uniforms/filterDOMProps';

const Radio = ({
    allowedValues,
    checkboxes, // eslint-disable-line no-unused-vars
    className,
    disabled,
    error,
    errorMessage,
    id,
    label,
    name,
    onChange,
    required,
    showInlineError,
    transform,
    value,
    ...props
}) =>
    <section className={classnames(className, {disabled, error}, 'grouped fields')} {...filterDOMProps(props)}>
        {label && (
            <section className={classnames({required}, 'field')}>
                <label>
                    {label}
                </label>
            </section>
        )}

        {allowedValues.map(item =>
            <section className="field" key={item}>
                <section className="ui radio checkbox">
                    <input
                        checked={item === value}
                        disabled={disabled}
                        id={`${id}-${item}`}
                        name={name}
                        onChange={() => onChange(item)}
                        type="radio"
                    />

                    <label htmlFor={`${id}-${item}`}>
                        {transform ? transform(item) : item}
                    </label>
                </section>
            </section>
        )}

        {!!(errorMessage && showInlineError) && (
            <section className="ui red basic pointing label">
                {errorMessage}
            </section>
        )}
    </section>
;

export default connectField(Radio);

==> uniforms-semantic-1.17.1.tgz: package/src/RadioField.js <==
import React          from 'react';
import classnames     from 'classnames';
import connectField   from 'uniforms/connectField';
import filterDOMProps from 'uniforms/filterDOMProps';

const Radio = ({
    allowedValues,
    checkboxes, // eslint-disable-line no-unused-vars
    className,
    disabled,
    error,
    errorMessage,
    id,
    label,
    name,
    onChange,
    required,
    showInlineError,
    transform,
    value,
    ...props
}) =>
    <div className={classnames(className, {disabled, error}, 'grouped fields')} {...filterDOMProps(props)}>
        {label && (
            <div className={classnames({required}, 'field')}>
                <label>
                    {label}
                </label>
            </div>
        )}

        {allowedValues.map(item =>
            <div className="field" key={item}>
                <div className="ui radio checkbox">
                    <input
                        checked={item === value}
                        disabled={disabled}
                        id={`${id}-${item}`}
                        name={name}
                        onChange={() => onChange(item)}
                        type="radio"
                    />

                    <label htmlFor={`${id}-${item}`}>
                        {transform ? transform(item) : item}
                    </label>
                </div>
            </div>
        )}

        {!!(errorMessage && showInlineError) && (
            <div className="ui red basic pointing label">
                {errorMessage}
            </div>
        )}
    </div>
;

export default connectField(Radio);
